GNPy: Optical Route Planning Library
=====================================================================

`GNPy <http://github.com/telecominfraproject/gnpy>`_ is an open-source,
community-developed library for building route planning and optimization tools
in real-world mesh optical networks. It is based on the Gaussian Noise Model.

.. toctree::
   :maxdepth: 4

   install
   json
   excel
   model
   gnpy-api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

